Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(323)

Unified Diff: webkit/dom_storage/dom_storage_cached_area.h

Issue 10799008: Web Inspector: count DOM storage cache memory for native snapshot (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/renderer/dom_storage/webstoragearea_impl.cc ('k') | webkit/dom_storage/dom_storage_cached_area.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/dom_storage/dom_storage_cached_area.h
diff --git a/webkit/dom_storage/dom_storage_cached_area.h b/webkit/dom_storage/dom_storage_cached_area.h
index fb6df402a2a9c1e15b3fef1cbe8bf17e968135f6..fc1968ed30f6f1f250944ec86c5bdd5ae6f76089 100644
--- a/webkit/dom_storage/dom_storage_cached_area.h
+++ b/webkit/dom_storage/dom_storage_cached_area.h
@@ -18,7 +18,7 @@ class DomStorageMap;
class DomStorageProxy;
// Unlike the other classes in the dom_storage library, this one is intended
// for use in renderer processes. It maintains a complete cach of the an
// origin's Map of key/value pairs for fast access. The cache is primed on
// first access and changes are written to the backend thru the |proxy|.
// Mutations originating in other processes are applied to the cache via
@@ -43,6 +43,8 @@ class DomStorageCachedArea : public base::RefCounted<DomStorageCachedArea> {
void ApplyMutation(const NullableString16& key,
const NullableString16& new_value);
+ size_t MemoryBytesUsedByCache() const;
+
private:
friend class DomStorageCachedAreaTest;
friend class base::RefCounted<DomStorageCachedArea>;
@@ -18,7 +18,7 @@ class DomStorageMap;
class DomStorageProxy;
// Unlike the other classes in the dom_storage library, this one is intended
-// for use in renderer processes. It maintains a complete cach of the an
+// for use in renderer processes. It maintains a complete cache of the
// origin's Map of key/value pairs for fast access. The cache is primed on
// first access and changes are written to the backend thru the |proxy|.
« no previous file with comments | « content/renderer/dom_storage/webstoragearea_impl.cc ('k') | webkit/dom_storage/dom_storage_cached_area.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698